#!/usr/bin/python3

import pytest
import yaml
import pkg_resources
from influxdb import InfluxDBClient


@pytest.fixture(scope="module")
def streaming_sim_config():
    """
    Reads the service configuration deployed for the streaming simulation test.

    :param request: access the parameters of the fixture
    :return: the python object representing the read YAML file
    """
    rspec = pkg_resources.resource_filename('clmctest.monitoring', 'rspec.yml')
    print("rspec file: {0}".format(rspec))

    with open(rspec, 'r') as stream:
        data_loaded = yaml.load(stream)
    return data_loaded


@pytest.fixture(params=[{'database': 'CLMCMetrics'}], scope='module')
def influxdb(streaming_sim_config, request):
    """
    Creates an Influx DB client for the CLMC metrics database

    :param streaming_sim_config: the fixture returning the yaml configuration
    :param request: access the parameters of the fixture
    :return: the created Influx DB client
    """

    db = InfluxDBClient(host=streaming_sim_config['hosts'][0]['ip_address'], port=8086, database=request.param['database'], timeout=10)
    db.drop_database(request.param['database'])
    
    return db
